@@ -7,7 +7,7 @@ __all__ = ['codeof','get_params','get_doc','log','find_db','DB','is_exist','make
 
 from .code import codeof,get_params,get_doc
 from .color_log import _print_ as log 
-from .db_func import find_db ,DB, is_exist
-from .helps import make_,validate
-from .text_parser import Parser 
+from .db_func import find_db ,DB
+from .helps import make_,validate,is_exist
+from .parser import Parser 
 from .string_func import String 
\ No newline at end of file
