@@ -6,7 +6,7 @@ import cv2
 
 
 
-def encode_qr(text,img_name="image.jpg"):
+def encode(text,img_name="image.jpg"):
     cont = qrcode.make(text)
     if img_name is not None:
         cont.save(img_name)
@@ -15,7 +15,7 @@ def encode_qr(text,img_name="image.jpg"):
         print('IMAGE Cannot be None ')
 
 
-def decode_qr(cont):
+def decode(cont):
     if cont is not None:
         img = cv2.imread(cont)
         decoder = cv2.QRCodeDetector()
